==> swarmapps-1.0.1.tar.gz: swarmapps-1.0.1/hello-world/v01/PplObserverSwarm.m <==
// Hello, World! application. Copyright (C) 1996 Santa Fe Institute.
// This library is distributed without any warranty; without even the
// implied warranty of merchantability or fitness for a particular purpose.
// See file LICENSE for details and terms of copying.

#import "PplObserverSwarm.h"

// implementation of sample graphical interface for models.
@implementation PplObserverSwarm

+ createBegin: aZone
{
  PplObserverSwarm * obj;
  id <ProbeMap> probeMap;
  
  obj = [super createBegin: aZone];

  // MODIFY: initialize other display options here.
  obj->displayFrequency = 1;

  probeMap = [EmptyProbeMap createBegin: aZone];
  [probeMap setProbedClass: [self class]];
  probeMap = [probeMap createEnd];

  // MODIFY: set any display parameters here.
  [probeMap addProbe: [probeLibrary getProbeForVariable: "displayFrequency"
				    inClass: [self class]]];

  [probeLibrary setProbeMap: probeMap For: [self class]];

  return obj;
}

// MODIFY: possible creation finalization here
- createEnd
{
  return [super createEnd];
}

- buildObjects
{
  id modelZone;

  [super buildObjects];
  
  // allocate space to hold the model
  modelZone = [Zone create: [self getZone]];
  // create the modelswarm as a subzone in the modelzone
  pplModelSwarm = [PplModelSwarm create: modelZone];
  
  // create the probedisplay manager for the model swarm
  [probeDisplayManager createProbeDisplayFor: pplModelSwarm];
  // create the probe display for the observer swarm (self)
  [probeDisplayManager createProbeDisplayFor: self];

  // set the control panel state
  [controlPanel waitForControlEvent];
  // test to see if the "quit" button was hit
  if ([controlPanel getState] == ControlStateQuit)
    return self;

  // build the objects defined in PplmodelSwarm.m
  [pplModelSwarm buildObjects];

  // display the counter
  observedCounter = [pplModelSwarm getCounter];

  return self;
}  

- buildActions
{
  // build the actions for the observer's schedule
  [super buildActions];
  
  // build the actions for the model's schedule
  [pplModelSwarm buildActions];

  // create the display actions
  displayActions = [ActionGroup create: [self getZone]];
  // update the counter
  [displayActions createActionTo: observedCounter     message: M(print)];
  // update the probes
  [displayActions createActionTo: probeDisplayManager message: M(update)];
  // check the controlpanel for clicks
  [displayActions createActionTo: actionCache        message: M(doTkEvents)];

  // then actually schedule the display actions
  displaySchedule = [Schedule createBegin: [self getZone]];
  [displaySchedule setRepeatInterval: displayFrequency];
  displaySchedule = [displaySchedule createEnd];
  [displaySchedule at: 0 createAction: displayActions];

  return self;
}  

- activateIn: swarmContext
{
  // put self (observer swarm) on the schedule of the GUI swarm
  [super activateIn: swarmContext];

  // start the activity for the model swarm
  [pplModelSwarm activateIn: self];
  // start the display schedule
  [displaySchedule activateIn: self];
  
  return [self getSwarmActivity];
}

@end

==> swarmapps-1.0.2.tar.gz: swarmapps-1.0.2/hello-world/v01/PplObserverSwarm.m <==
// Hello, World! application. Copyright (C) 1996-1998 Santa Fe Institute.
// This library is distributed without any warranty; without even the
// implied warranty of merchantability or fitness for a particular purpose.
// See file LICENSE for details and terms of copying.

#import "PplObserverSwarm.h"

// implementation of sample graphical interface for models.
@implementation PplObserverSwarm

+ createBegin: aZone
{
  PplObserverSwarm * obj;
  id <ProbeMap> probeMap;
  
  obj = [super createBegin: aZone];

  // MODIFY: initialize other display options here.
  obj->displayFrequency = 1;

  probeMap = [EmptyProbeMap createBegin: aZone];
  [probeMap setProbedClass: [self class]];
  probeMap = [probeMap createEnd];

  // MODIFY: set any display parameters here.
  [probeMap addProbe: [probeLibrary getProbeForVariable: "displayFrequency"
				    inClass: [self class]]];

  [probeLibrary setProbeMap: probeMap For: [self class]];

  return obj;
}

// MODIFY: possible creation finalization here
- createEnd
{
  return [super createEnd];
}

- buildObjects
{
  id modelZone;

  [super buildObjects];
  
  // allocate space to hold the model
  modelZone = [Zone create: [self getZone]];
  // create the modelswarm as a subzone in the modelzone
  pplModelSwarm = [PplModelSwarm create: modelZone];
  
  // create the probedisplay manager for the model swarm
  CREATE_PROBE_DISPLAY (pplModelSwarm);
  // create the probe display for the observer swarm (self)
  CREATE_PROBE_DISPLAY (self);

  // set the control panel state
  [controlPanel waitForControlEvent];
  // test to see if the "quit" button was hit
  if ([controlPanel getState] == ControlStateQuit)
    return self;

  // build the objects defined in PplmodelSwarm.m
  [pplModelSwarm buildObjects];

  // display the counter
  observedCounter = [pplModelSwarm getCounter];

  return self;
}  

- buildActions
{
  // build the actions for the observer's schedule
  [super buildActions];
  
  // build the actions for the model's schedule
  [pplModelSwarm buildActions];

  // create the display actions
  displayActions = [ActionGroup create: [self getZone]];
  // update the counter
  [displayActions createActionTo: observedCounter     message: M(print)];
  // update the probes
  [displayActions createActionTo: probeDisplayManager message: M(update)];
  // check the controlpanel for clicks
  [displayActions createActionTo: actionCache        message: M(doTkEvents)];

  // then actually schedule the display actions
  displaySchedule = [Schedule createBegin: [self getZone]];
  [displaySchedule setRepeatInterval: displayFrequency];
  displaySchedule = [displaySchedule createEnd];
  [displaySchedule at: 0 createAction: displayActions];

  return self;
}  

- activateIn: swarmContext
{
  // put self (observer swarm) on the schedule of the GUI swarm
  [super activateIn: swarmContext];

  // start the activity for the model swarm
  [pplModelSwarm activateIn: self];
  // start the display schedule
  [displaySchedule activateIn: self];
  
  return [self getSwarmActivity];
}

@end
